@@ -7,14 +7,15 @@ __all__ = [
     "denorm",
     "norm",
 ]
-__version__ = "0.3.3"
+__version__ = "0.4.0"
 
 from .common.noise import gaussian, gaussian_like, uniform_int, pad
 from .common.vis import make_history
 from .common.norm import denorm, norm
 
+from . import data
+
 from .lit_modules import *
 
 from . import diffusion_models
-
-from dmme import equations
+from . import equations
